package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Intbox;
import org.zkoss.zul.Paging;
import org.zkoss.zul.api.Datebox;

import com.rjconsultores.ventaboletos.entidad.Feriado;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.MyTextbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderFeriado;

@Controller("busquedaConfigFeriadoController")
@Scope("prototype")
public class BusquedaConfigFeriadoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	@Autowired
	private transient PagedListWrapper<Feriado> plwFeriado;
	private MyListbox configFeriadoList;
	private Paging pagingConfigFeriado;

	private MyTextbox textboxDescricao;
	private Intbox txtID;
	private Datebox fecFeriado;


	public MyTextbox getTextboxDescricao() {
		return textboxDescricao;
	}

	public void setTextboxDescricao(MyTextbox textboxDescricao) {
		this.textboxDescricao = textboxDescricao;
	}

	public Intbox getTxtID() {
		return txtID;
	}

	public void setTxtID(Intbox txtID) {
		this.txtID = txtID;
	}

	public Datebox getFecFeriado() {
		return fecFeriado;
	}

	public void setFecFeriado(Datebox fecFeriado) {
		this.fecFeriado = fecFeriado;
	}

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);

		

		configFeriadoList.setItemRenderer(new RenderFeriado());
		configFeriadoList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				Feriado c = (Feriado) configFeriadoList.getSelected();
				verFeriado(c);
			}
		});

		refreshLista();

		
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verFeriado(Feriado a) {
		if (a == null) {
			return;
		}

		Map args = new HashMap();
		args.put("feriado", a);
		args.put("configFeriadoList", configFeriadoList);

		openWindow("/gui/configuraciones_comerciales/editarConfigFeriado.zul",
				Labels.getLabel("busquedaConfigFeriadoController.window.title"), args, MODAL);
	}

	private void refreshLista() {
		HibernateSearchObject<Feriado> feriado=
				new HibernateSearchObject<Feriado>(Feriado.class,
						pagingConfigFeriado.getPageSize());
		

		Integer idFeriado= txtID.getValue();
		if (idFeriado != null) {
			feriado.addFilterEqual("feriadoId", idFeriado);
		}
		

		String descricao = textboxDescricao.getText();
		
        if ((descricao != null) ) {
			feriado.addFilterLike("descferiado", "%" + descricao.trim().concat("%"));
		}
        
        if (fecFeriado.getValue() != null) {
            Date data = fecFeriado.getValue();
            data.setHours(00);
            data.setMinutes(00);
            data.setSeconds(00);
            feriado.addFilterEqual("fecferiado",data);
        }

        feriado.addFilterEqual("activo", Boolean.TRUE);
        feriado.addSortAsc("descferiado");        
        feriado.addFilterNotEqual("feriadoId", -1);
	

		plwFeriado.init(feriado, configFeriadoList, pagingConfigFeriado);
		if (configFeriadoList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaAlertaCtrlController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verFeriado(new Feriado());
	}

	
}

